Learn R Programming

BayesERtools (version 0.2.0)

BayesERtools-package: BayesERtools: Bayesian Exposure-Response Analysis Tools

Description

logo

Suite of tools that facilitate exposure-response analysis using Bayesian methods. The package provides a streamlined workflow for fitting types of models that are commonly used in exposure-response analysis - linear and Emax for continuous endpoints, logistic linear and logistic Emax for binary endpoints, as well as performing simulation and visualization. Learn more about the workflow at https://genentech.github.io/BayesERbook/.

Arguments

Author

Maintainer: Kenta Yoshida yoshida.kenta.6@gmail.com (ORCID)

Authors:

Other contributors:

  • Genentech, Inc. [copyright holder]

See Also